@@ -2,12 +2,14 @@
 eval 'exec /usr/bin/perl -S $0 ${1+"$@"}'
     if 0;    # not running under some shell
 
+# This script shows how POD => HTML works
+
 use Pod::HtmlEasy ;
 
 use strict ;
 use warnings ;
   
-if ( $ARGV[0] =~ /^-+h/i || !@ARGV ) {
+if ( !@ARGV || $ARGV[0] =~ /^-+h/i ) {
 
   my ($script) = ( $0 =~ /([^\\\/]+)$/s );
 
@@ -18,7 +20,7 @@ ____________________________________________________________________
 
 USAGE:
 
-  $script file.pod file.html
+  $script file.pod [file.html]
 
 
 (C) Copyright 2000-2004, Graciliano M. P. <gm\@virtuasites.com.br>
